.. _package-plugins:

:mod:`Plugins` Package
======================

.. automodule:: odoo_rpc_client.plugins
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`module_utils` Plugin
--------------------------

.. automodule:: odoo_rpc_client.plugins.module_utils
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`external_ids` Plugin
--------------------------

.. automodule:: odoo_rpc_client.plugins.external_ids
    :members:
    :undoc-members:
    :show-inheritance:
